# resume-model

This is a Python project scaffolded with scaffoldpy. Here is what you need to do next:
1. Install the dependencies: `uv sync --all-groups`
2. Install the pre-commit hooks: `pre-commit install`
3. Create repo on Github
4. Run `git remote add origin https://github.com/austinyu/<repo-name>.git`
5. Push to remote: `git push -u origin main`
6. Register your project on PyPi
7. Release a new version on github.
8. Release pipeline will automatically publish the package to PyPi.
